==> tw-server-common-2.1.7-20230616.023833-3-sources.jar: com/elitesland/tw/tw5/server/prd/app/controller/AppVersionController.java <==
package com.elitesland.tw.tw5.server.prd.app.controller;

import com.elitesland.tw.tw5.api.prd.app.payload.AppVersionPayload;
import com.elitesland.tw.tw5.api.prd.app.query.AppVersionQuery;
import com.elitesland.tw.tw5.api.prd.app.service.AppVersionService;
import com.elitesland.tw.tw5.server.common.TwOutputUtil;
import com.elitesland.tw.tw5.server.prd.common.GlobalUtil;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.web.bind.annotation.*;

import java.util.Arrays;

/**
 * APP版本管理
 *
 * @author duwh
 * @date 2023-02-23
 */
@RestController
@RequiredArgsConstructor
@RequestMapping("/api/app/appVersion")
@Slf4j
public class AppVersionController {

    private final AppVersionService appVersionService;

    /**
     * 新增
     *
     * @param payload 有效载荷
     * @return {@link TwOutputUtil}
     */
    @PostMapping
    public TwOutputUtil insert(@RequestBody AppVersionPayload payload) {
        GlobalUtil.getLoginUserId();
        return TwOutputUtil.ok(appVersionService.insert(payload));
    }

    /**
     * 更新
     *
     * @param payload 有效载荷
     * @return {@link TwOutputUtil}
     */
    @PutMapping
    public TwOutputUtil update(@RequestBody AppVersionPayload payload) {
        GlobalUtil.getLoginUserId();
        return TwOutputUtil.ok(appVersionService.update(payload));
    }

    /**
     * 主键查询
     *
     * @param key 关键
     * @return {@link TwOutputUtil}
     */
    @GetMapping("/{key}")
    // @UdcNameClass
    public TwOutputUtil queryOneByKey(@PathVariable Long key) {
        GlobalUtil.getLoginUserId();
        return TwOutputUtil.ok(appVersionService.queryByKey(key));
    }

    /**
     * 分页
     *
     * @param query 查询
     * @return {@link TwOutputUtil}
     */
    @GetMapping("/paging")
    // @UdcNameClass
    public TwOutputUtil paging(AppVersionQuery query) {
        GlobalUtil.getLoginUserId();
        return TwOutputUtil.ok(appVersionService.paging(query));
    }

    /**
     * 获得当前版本
     *
     * @return {@link TwOutputUtil}
     */
    @GetMapping("/getCurrentVersion")
    // @UdcNameClass
//    @Deprecated
    public TwOutputUtil getCurrentVersion() {
        GlobalUtil.getLoginUserId();
        return TwOutputUtil.ok(appVersionService.getCurrentVersion());
    }

    /**
     * 删除
     *
     * @param keys 主键id
     * @return result
     */
    @DeleteMapping("/deleteSoft")
    public TwOutputUtil deleteSoft(Long[] keys) {
        GlobalUtil.getLoginUserId();
        appVersionService.deleteSoft(Arrays.asList(keys));
        return TwOutputUtil.ok();
    }

}

==> tw-server-common-3.0.1-20230927.093446-1-sources.jar: com/elitesland/tw/tw5/server/prd/app/controller/AppVersionController.java <==
package com.elitesland.tw.tw5.server.prd.app.controller;

import com.elitesland.tw.tw5.api.prd.app.payload.AppVersionPayload;
import com.elitesland.tw.tw5.api.prd.app.query.AppVersionQuery;
import com.elitesland.tw.tw5.api.prd.app.service.AppVersionService;
import com.elitesland.tw.tw5.api.common.TwOutputUtil;
import com.elitesland.tw.tw5.server.prd.common.GlobalUtil;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.web.bind.annotation.*;

import java.util.Arrays;

/**
 * APP版本管理
 *
 * @author duwh
 * @date 2023-02-23
 */
@RestController
@RequiredArgsConstructor
@RequestMapping("/api/app/appVersion")
@Slf4j
public class AppVersionController {

    private final AppVersionService appVersionService;

    /**
     * 新增
     *
     * @param payload 有效载荷
     * @return {@link TwOutputUtil}
     */
    @PostMapping
    public TwOutputUtil insert(@RequestBody AppVersionPayload payload) {
        GlobalUtil.getLoginUserId();
        return TwOutputUtil.ok(appVersionService.insert(payload));
    }

    /**
     * 更新
     *
     * @param payload 有效载荷
     * @return {@link TwOutputUtil}
     */
    @PutMapping
    public TwOutputUtil update(@RequestBody AppVersionPayload payload) {
        GlobalUtil.getLoginUserId();
        return TwOutputUtil.ok(appVersionService.update(payload));
    }

    /**
     * 主键查询
     *
     * @param key 关键
     * @return {@link TwOutputUtil}
     */
    @GetMapping("/{key}")
    // @UdcNameClass
    public TwOutputUtil queryOneByKey(@PathVariable Long key) {
        GlobalUtil.getLoginUserId();
        return TwOutputUtil.ok(appVersionService.queryByKey(key));
    }

    /**
     * 分页
     *
     * @param query 查询
     * @return {@link TwOutputUtil}
     */
    @GetMapping("/paging")
    // @UdcNameClass
    public TwOutputUtil paging(AppVersionQuery query) {
        GlobalUtil.getLoginUserId();
        return TwOutputUtil.ok(appVersionService.paging(query));
    }

    /**
     * 获得当前版本
     *
     * @return {@link TwOutputUtil}
     */
    @GetMapping("/getCurrentVersion")
    // @UdcNameClass
//    @Deprecated
    public TwOutputUtil getCurrentVersion() {
        GlobalUtil.getLoginUserId();
        return TwOutputUtil.ok(appVersionService.getCurrentVersion());
    }

    /**
     * 删除
     *
     * @param keys 主键id
     * @return result
     */
    @DeleteMapping("/deleteSoft")
    public TwOutputUtil deleteSoft(Long[] keys) {
        GlobalUtil.getLoginUserId();
        appVersionService.deleteSoft(Arrays.asList(keys));
        return TwOutputUtil.ok();
    }

}
